#!/usr/bin/gnuplot
# the execute instruction line above only works in unix

# usage example (all on one line): gnuplot -e "grafile='graph-file.pdf'; 
#   starttime='2019-07-24T23:30'; stoptime='2019-07-26T23:30'" basic.gp

#functions

#find average of several columns
av(a,b,c,d) = (a+b+c+d)/4

# saturation vapour pressure at temperature t
svp(t) = 610*exp(t/(t+238.3)*17.2694)

# actual vapour pressure at temperature=t and rh%=rh
vp(t,rh) = svp(t)*rh/100

# rh expected at surface with different temperature than nearby RH sensor
rhsurface(tsensor, rhsensor, tsurface) = 100.0 * mixr(tsensor,rhsensor)/mixr(tsurface,100)


w(t,rh) = log(vp(t,rh)/610.78)
dpt(t,rh) = (w(t,rh)*238.3)/(17.294-w(t,rh))
gm3(t,rh) = vp(t,rh)*2.166/(t + 273.16)

# Mixing ratio g/kg
mixr(t,rh) = (0.62 *10**(-5)*vp(t,rh))*1000 
# Expected RH with no buffer
exprh(tout,rhout,tin) = 100*vp(tout,rhout)/svp(tin)

#end of functions

set output grafile

set encoding utf8
set term pdfcairo enhanced color solid font 'Helvetica,16' size 32cm,16cm 
#set lmargin at screen 0.09
set notitle
#set title "Buffered over insulation, 18 {/Symbol \260}C average, 12 hour cycle" font "Helvetica,20"
set xdata time
set timefmt "%Y-%m-%dT%H:%M:%S"
set format x "%d/%H"
set xlabel "Day/hour" font "Helvetica,18" 
#set xtics 3600
#set xrange ["2019-07-24T23:30": "2019-07-26T23:30"]
set xrange [starttime:stoptime]
set yrange [16:38]
set ytics 16,2,38
set mytics 4
set ylabel "Temperature ({/Symbol \260}C)" font "Helvetica,18"
set key below left height 1.5
set grid x
set grid mytics
set grid y

#set label 'RH' at graph 0.02,0.80
#set label 'Temperature' at graph 0.02,0.51
#set label 'MR' at graph 0.02,0.12
set style fill transparent solid 0.5 noborder
plot "logdata-all.txt" \
using 1:7 t 'pt-100 reference' with lines ls 16 lw 1 \
,'' using 1:13  t 'room' with lines ls 4 lw 1 \
,'' using 1:11  t 'back plate' with lines ls 5 lw 1 \
,'' using 1:17  t 'canvas' with lines ls 7 lw 1 \
,'' using 1:15  t 'beam' with lines lc rgb "#000000" lw 1 \




